/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/* 
 * langtag.h
 * Copyright (C) 2011-2012 Akira TAGOH
 * 
 * Authors:
 *   Akira TAGOH  <akira@tagoh.org>
 * 
 * You may distribute under the terms of either the GNU
 * Lesser General Public License or the Mozilla Public
 * License, as specified in the README file.
 */
#ifndef __LANGTAG_H__
#define __LANGTAG_H__

#define __LANGTAG_H__INSIDE
#include <liblangtag/lt-error.h>
#include <liblangtag/lt-database.h>
#include <liblangtag/lt-ext-module.h>
#include <liblangtag/lt-extension.h>
#include <liblangtag/lt-iter.h>
#include <liblangtag/lt-list.h>
#include <liblangtag/lt-redundant.h>
#include <liblangtag/lt-string.h>
#include <liblangtag/lt-tag.h>
#undef __LANGTAG_H__INSIDE

#endif /* __LANGTAG_H__ */
